@@ -1,9 +1,10 @@
 import attr
 import datetime
+from typing import List, Dict
 
 
 @attr.s(auto_attribs=True, frozen=True)
-class DeviceState:
+class Device:
     """Object holding the Aqman101 device state."""
 
     serial_number: str
@@ -24,14 +25,14 @@ class DeviceState:
 
     @staticmethod
     def from_dict(data):
-        return DeviceState(
+        return Device(
             serial_number=data["sn"],
             dsm101_serial_number=data["dsm101_sn"],
             date_time=data["dt"],
-            device_type=data["devType"],
-            firmware_version=data["version"],
-            upload_type=data["uploadType"],
-            smartplug_enable=data["plugEnable"],
+            device_type=0,
+            firmware_version="V1.02A",
+            upload_type=0,
+            smartplug_enable=0,
             temperature=data["temp"],
             humidity=data["humi"],
             radon=data["radon"],
@@ -41,3 +42,22 @@ class DeviceState:
             pm1=data["pm1"],
             tvoc=data["tvoc"]
         )
+
+
+@attr.s(auto_attribs=True, frozen=True)
+class UserInfo:
+    """Object holding the user information of Aqman101 user"""
+
+    username: str
+    password: str
+    devices: List[str]
+    device_cnt: int
+
+    @staticmethod
+    def from_list(username: str, password: str, data: List[Dict]):
+        device_list: List[str] = []
+
+        for device in data:
+            device_list.append(device['sn'])
+
+        return UserInfo(username, password, device_list, len(device_list))
